@@ -1,38 +1,23 @@
-import sys
 from concurrent.futures import as_completed
 from concurrent.futures.thread import ThreadPoolExecutor
-from typing import Any, Optional
 
 from sslyze.cli.output_hub import OutputHub
 from sslyze.__version__ import __version__
 from sslyze.cli.command_line_parser import CommandLineParsingError, CommandLineParser
-import signal
 from time import time
 
 from sslyze.errors import ConnectionToServerFailed
 from sslyze.scanner import Scanner, ServerScanRequest
 from sslyze.server_connectivity import ServerConnectivityTester
 
-global_scanner: Optional[Scanner] = None
-
-
-def sigint_handler(signum: int, frame: Any) -> None:
-    print("Scan interrupted... shutting down.")
-    if global_scanner:
-        global_scanner.emergency_shutdown()
-    sys.exit()
-
 
 def main() -> None:
-    global global_scanner
-
-    # Handle SIGINT to terminate processes
-    signal.signal(signal.SIGINT, sigint_handler)
     start_time = time()
 
     # Create the command line parser and the list of available options
     sslyze_parser = CommandLineParser(__version__)
     try:
+        # Parse the supplied command line
         parsed_command_line = sslyze_parser.parse_command_line()
     except CommandLineParsingError as e:
         print(e.get_error_msg())
@@ -41,13 +26,9 @@ def main() -> None:
     output_hub = OutputHub()
     output_hub.command_line_parsed(parsed_command_line)
 
-    global_scanner = Scanner(
-        per_server_concurrent_connections_limit=parsed_command_line.per_server_concurrent_connections_limit,
-        concurrent_server_scans_limit=parsed_command_line.concurrent_server_scans_limit,
-    )
-
-    # Figure out which hosts are up and fill the task queue with work to do
+    # Figure out which servers are reachable
     connectivity_tester = ServerConnectivityTester()
+    all_server_scan_requests = []
     with ThreadPoolExecutor(max_workers=10) as thread_pool:
         futures = [
             thread_pool.submit(connectivity_tester.perform, server_location, network_config)
@@ -58,22 +39,29 @@ def main() -> None:
                 server_connectivity_info = completed_future.result()
                 output_hub.server_connectivity_test_succeeded(server_connectivity_info)
 
-                # Send scan commands for this server to the scanner
+                # Server is only; add it to the list of servers to scan
                 scan_request = ServerScanRequest(
                     server_info=server_connectivity_info,
                     scan_commands=parsed_command_line.scan_commands,
                     scan_commands_extra_arguments=parsed_command_line.scan_commands_extra_arguments,
                 )
-                global_scanner.queue_scan(scan_request)
+                all_server_scan_requests.append(scan_request)
 
             except ConnectionToServerFailed as e:
                 output_hub.server_connectivity_test_failed(e)
 
+    # For the servers that are reachable, start the scans
     output_hub.scans_started()
+    if all_server_scan_requests:
+        sslyze_scanner = Scanner(
+            per_server_concurrent_connections_limit=parsed_command_line.per_server_concurrent_connections_limit,
+            concurrent_server_scans_limit=parsed_command_line.concurrent_server_scans_limit,
+        )
+        sslyze_scanner.start_scans(all_server_scan_requests)
 
-    # Process the results as they come
-    for scan_result in global_scanner.get_results():
-        output_hub.server_scan_completed(scan_result)
+        # Process the results as they come
+        for scan_result in sslyze_scanner.get_results():
+            output_hub.server_scan_completed(scan_result)
 
     # All done
     exec_time = time() - start_time
