@@ -1,6 +1,5 @@
 import socket
 import types
-from concurrent.futures._base import Future
 from dataclasses import dataclass
 from typing import List, Optional
 
@@ -13,6 +12,7 @@ from sslyze.plugins.plugin_base import (
     ScanJob,
     ScanCommandWrongUsageError,
     ScanCommandCliConnector,
+    ScanJobResult,
 )
 from tls_parser.alert_protocol import TlsAlertRecord
 from tls_parser.application_data_protocol import TlsApplicationDataRecord
@@ -70,12 +70,12 @@ class OpenSslCcsInjectionImplementation(ScanCommandImplementation[OpenSslCcsInje
 
     @classmethod
     def result_for_completed_scan_jobs(
-        cls, server_info: ServerConnectivityInfo, completed_scan_jobs: List[Future]
+        cls, server_info: ServerConnectivityInfo, scan_job_results: List[ScanJobResult]
     ) -> OpenSslCcsInjectionScanResult:
-        if len(completed_scan_jobs) != 1:
-            raise RuntimeError(f"Unexpected number of scan jobs received: {completed_scan_jobs}")
+        if len(scan_job_results) != 1:
+            raise RuntimeError(f"Unexpected number of scan jobs received: {scan_job_results}")
 
-        return OpenSslCcsInjectionScanResult(is_vulnerable_to_ccs_injection=completed_scan_jobs[0].result())
+        return OpenSslCcsInjectionScanResult(is_vulnerable_to_ccs_injection=scan_job_results[0].get_result())
 
 
 def _test_for_ccs_injection(server_info: ServerConnectivityInfo) -> bool:
